==> haskell-hls-pragmas-plugin-2.1.0.0-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-pragmas-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-pragmas-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-pragmas-plugin-2.1.0.0-38EDWIyumVJG9pDZnn397G
key:                  hls-pragmas-plugin-2.1.0.0-38EDWIyumVJG9pDZnn397G
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Pragmas plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  cb885d0480c3fcb6c73c9691582254b2
exposed:              True
exposed-modules:      Ide.Plugin.Pragmas
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-pragmas-plugin
hs-libraries:         HShls-pragmas-plugin-2.1.0.0-38EDWIyumVJG9pDZnn397G
depends:
    base-4.17.2.1 containers-0.6.7 extra-1.7.16-4PSPnwgFT0S5iaiPzXfiD0
    fuzzy-0.1.1.0-AAUNI8fRDAtFn1aVD9ozaz ghc-9.4.8
    ghcide-2.1.0.0-3Ox1FIoKR986pmNDYa5rJ1
    hls-plugin-api-2.1.0.0-A1WQzAmngyS25z3H8OuQE8
    lens-5.3.2-Do7BRGZKCykCgu16LW7xBK
    lsp-2.1.0.0-92Yl297Q9DW4BeMdYNCf6v text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-2N1fR83O3bC5qS2nrjaL2B

haddock-interfaces:
    /usr/share/doc/haskell-hls-pragmas-plugin/html/hls-pragmas-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-pragmas-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-pragmas-plugin-2.1.0.0-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-pragmas-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-pragmas-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-pragmas-plugin-2.1.0.0-1mkAuM5yHDg3SymJo6Z4ek
key:                  hls-pragmas-plugin-2.1.0.0-1mkAuM5yHDg3SymJo6Z4ek
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Pragmas plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  ad188dd94c574c93fec5a705d925519f
exposed:              True
exposed-modules:      Ide.Plugin.Pragmas
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-pragmas-plugin
hs-libraries:         HShls-pragmas-plugin-2.1.0.0-1mkAuM5yHDg3SymJo6Z4ek
depends:
    base-4.17.2.1 containers-0.6.7 extra-1.7.16-4PSPnwgFT0S5iaiPzXfiD0
    fuzzy-0.1.1.0-AAUNI8fRDAtFn1aVD9ozaz ghc-9.4.8
    ghcide-2.1.0.0-FzPM2kBc4xorjD0nKMMOc
    hls-plugin-api-2.1.0.0-IF2mjrMBh4aKpRc7AO1ZaH
    lens-5.3.3-6cCVIdNEssO9Q1Aw8HDGhY
    lsp-2.1.0.0-JRAvMRSrlV11n1YRb0fu3x text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-2N1fR83O3bC5qS2nrjaL2B

haddock-interfaces:
    /usr/share/doc/haskell-hls-pragmas-plugin/html/hls-pragmas-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-pragmas-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
